@@ -708,7 +708,7 @@ func TestEvalCall(t *testing.T) {
 		{src: ` test := func(a, b int) int { return a }
 				blah := func() (int, float64) { return 1, 1.1 }
 				a := test(blah())`, err: "3:15: cannot use func() (int,float64) as type (int,int)"},
-		{src: "func f()", err: "function declaration without body is unsupported"},
+		{src: "func f()", err: "missing function body"},
 	})
 }
 
@@ -1095,6 +1095,10 @@ func main() {
 }
 
 func TestImportPathIsKey(t *testing.T) {
+	// FIXME(marc): support of stdlib generic packages like "cmp", "maps", "slices" has changed
+	// the scope layout by introducing new source packages when stdlib is used.
+	// The logic of the following test doesn't apply anymore.
+	t.Skip("This test needs to be reworked.")
 	// No need to check the results of Eval, as TestFile already does it.
 	i := interp.New(interp.Options{GoPath: filepath.FromSlash("../_test/testdata/redeclaration-global7")})
 	if err := i.Use(stdlib.Symbols); err != nil {
@@ -1252,10 +1256,9 @@ func TestConcurrentEvals2(t *testing.T) {
 			if hello1 {
 				if l == "hello world2" {
 					break
-				} else {
-					done <- fmt.Errorf("unexpected output: %v", l)
-					return
 				}
+				done <- fmt.Errorf("unexpected output: %v", l)
+				return
 			}
 			if l == "hello world1" {
 				hello1 = true
@@ -1335,7 +1338,7 @@ func TestConcurrentEvals3(t *testing.T) {
 		}()
 
 		for _, v := range input {
-			in := strings.NewReader(fmt.Sprintf("println(\"%s\")\n", v))
+			in := strings.NewReader(fmt.Sprintf("println(%q)\n", v))
 			if _, err := io.Copy(poutin, in); err != nil {
 				t.Fatal(err)
 			}
@@ -1880,25 +1883,25 @@ func TestIssue1383(t *testing.T) {
 			}
 		`
 
-	interp := interp.New(interp.Options{})
-	err := interp.Use(stdlib.Symbols)
+	i := interp.New(interp.Options{})
+	err := i.Use(stdlib.Symbols)
 	if err != nil {
 		t.Fatal(err)
 	}
-	_, err = interp.Eval(`import "fmt"`)
+	_, err = i.Eval(`import "fmt"`)
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	ast, err := parser.ParseFile(interp.FileSet(), "_.go", src, parser.DeclarationErrors)
+	ast, err := parser.ParseFile(i.FileSet(), "_.go", src, parser.DeclarationErrors)
 	if err != nil {
 		t.Fatal(err)
 	}
-	prog, err := interp.CompileAST(ast)
+	prog, err := i.CompileAST(ast)
 	if err != nil {
 		t.Fatal(err)
 	}
-	_, err = interp.Execute(prog)
+	_, err = i.Execute(prog)
 	if err != nil {
 		t.Fatal(err)
 	}
