@@ -1,6 +1,7 @@
 package interp
 
 import (
+	"errors"
 	"fmt"
 	"io/fs"
 	"os"
@@ -208,7 +209,7 @@ func (interp *Interpreter) pkgDir(goPath string, root, importPath string) (strin
 		return dir, root, nil // found!
 	}
 
-	if len(root) == 0 {
+	if root == "" {
 		if interp.context.GOPATH == "" {
 			return "", "", fmt.Errorf("unable to find source related to: %q. Either the GOPATH environment variable, or the Interpreter.Options.GoPath needs to be set", importPath)
 		}
@@ -245,7 +246,7 @@ func previousRoot(filesystem fs.FS, rootPath, root string) (string, error) {
 				vendored = strings.TrimPrefix(strings.TrimPrefix(parent, prefix), string(filepath.Separator))
 				break
 			}
-			if !os.IsNotExist(err) {
+			if !errors.Is(err, fs.ErrNotExist) {
 				return "", err
 			}
 			// stop when we reach GOPATH/src
