@@ -1,6 +1,3 @@
-//go:build go1.19
-// +build go1.19
-
 // Package unsafe provides wrapper of standard library unsafe package to be imported natively in Yaegi.
 package unsafe
 
@@ -20,10 +17,13 @@ func init() {
 		"convert": reflect.ValueOf(convert),
 	}
 
-	// Add builtin functions to unsafe.
+	Symbols["unsafe/unsafe"]["Add"] = reflect.ValueOf(add)
+
+	// Add builtin functions to unsafe, also implemented in interp/cfg.go.
 	Symbols["unsafe/unsafe"]["Sizeof"] = reflect.ValueOf(sizeof)
 	Symbols["unsafe/unsafe"]["Alignof"] = reflect.ValueOf(alignof)
-	Symbols["unsafe/unsafe"]["Offsetof"] = reflect.ValueOf("Offsetof") // This symbol is handled directly in interpreter.
+	// The following is used for signature check only.
+	Symbols["unsafe/unsafe"]["Offsetof"] = reflect.ValueOf(func(interface{}) uintptr { return 0 })
 }
 
 func convert(from, to reflect.Type) func(src, dest reflect.Value) {
@@ -50,6 +50,10 @@ func convert(from, to reflect.Type) func(src, dest reflect.Value) {
 	}
 }
 
+func add(ptr unsafe.Pointer, l int) unsafe.Pointer {
+	return unsafe.Add(ptr, l)
+}
+
 func sizeof(i interface{}) uintptr {
 	return reflect.ValueOf(i).Type().Size()
 }
